@@ -277,7 +277,7 @@ async fn stake_rewards_from_warp() {
     assert_matches!(
         stake
             .delegation
-            .stake_activating_and_deactivating(clock.epoch, Some(&stake_history), true,),
+            .stake_activating_and_deactivating(clock.epoch, Some(&stake_history)),
         (_, 0, 0)
     );
 }
